pub struct Runtime<'config> { /* private fields */ }Expand description
EVM runtime.
The runtime wraps an EVM Machine with support of return data and context.
Implementations
Sourceimpl<'config> Runtime<'config>
impl<'config> Runtime<'config>
Sourcepub fn new(
code: Rc<Vec<u8>>,
data: Rc<Vec<u8>>,
context: Context,
config: &'config Config,
) -> Runtime<'config>
pub fn new( code: Rc<Vec<u8>>, data: Rc<Vec<u8>>, context: Context, config: &'config Config, ) -> Runtime<'config>
Create a new runtime with given code and data.